"""
Module contains common validators
"""
from .bases import isPydanticFirst

if not isPydanticFirst:  # TODO: remove after LUNA-6371 completed  # pylint: disable-msg=fixme
    from typing import Any

    from pydantic import ValidationError
    from pydantic_core import PydanticCustomError
    from pydantic_core.core_schema import ValidationInfo, ValidatorFunctionWrapHandler

    from ..errors.pydantic_errors import PydanticError as Error

    def validateFieldRequired(values: dict, field: str) -> dict:
        """Validates that 'values' is a dict and has a key <field>"""
        if not isinstance(values, dict):
            raise Error.PydanticInvalidDictError()
        if values.get(field) is None:
            raise Error.PydanticExactFieldRequiredError.format(field)()
        return values

    def excludeDiscriminatorFromException(
        values: Any, handler: ValidatorFunctionWrapHandler, info: ValidationInfo
    ):  # pylint: disable-msg=unused-argument
        """
        WrapValidator function that is applied on Union pydantic fields with discriminator
        to exclude discriminator value from exception location ('loc') on trace
        """
        try:
            return handler(values)
        except ValidationError as exc:
            error = exc.errors()[0]
            customError = PydanticCustomError(error["type"], error["msg"], error.get("ctx"))
            raise ValidationError.from_exception_data(
                error["type"],
                [{"type": customError, "loc": error["loc"][1:], "input": error["input"], "ctx": error.get("ctx", {})}],
            )
